package com.platform.yijia.service.impl;

import com.platform.yijia.dao.PayOrderMapper;
import com.platform.yijia.param.request.PayOrderRequest;
import com.platform.yijia.pojo.AppUserInfo;
import com.platform.yijia.pojo.PayOrder;

import com.platform.yijia.pojo.PayOrderExample;
import com.platform.yijia.service.PayOrderService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@Service("payOrderService")
public class PayOrderServiceImpl implements PayOrderService {
    @Resource
    private PayOrderMapper payOrderMapper;

    /*
     * 添加订单信息
     * @param payOrderRequest
     * @param payOrder
     * @return
     */
    @Override
    @Transactional
    public String AddPayOrderInfo(PayOrderRequest payOrderRequest, PayOrder payOrder) {
        //订单规则 时间+6位随机数
        Random random = new Random();
        String result="";
        for(int i=0;i<6;i++){
            result+=random.nextInt(10);
        }
        //System.out.println("随机生成6位数result ："+result);
        String ordNo=System.nanoTime()+result;
        payOrder.setOrderNo(ordNo);
        String oilName = payOrderRequest.getOilName();
        payOrder.setOilName(oilName);      //油品名称
        //根据油品名称存储油品类型 1.柴油 2 汽油
        switch (oilName){
            case "92#":
                payOrder.setOilType("2");
                break;
            case "95#":
                payOrder.setOilType("2");
                break;
            case "97#":
                payOrder.setOilType("2");
                break;
            case "0#":
                payOrder.setOilType("1");
                break;
            case "-10#":
                payOrder.setOilType("1");
                break;
            case "-20#":
                payOrder.setOilType("1");
                break;
        }
        payOrder.setReceivableAmt(payOrderRequest.getReceivableAmt());  //应收金额
        payOrder.setDiscountAmt(payOrderRequest.getDiscountAmt());  //优惠金额
        payOrder.setDiscountCouponAmt(payOrderRequest.getDiscountCouponAmt());  //优惠劵金额
        payOrder.setDiscountCoupon(payOrderRequest.getDiscountCoupon());        //优惠券
        payOrder.setCarNo(payOrderRequest.getCarNo());  //车牌号、
        payOrder.setCustomerGrade(payOrderRequest.getCustomerGrade());    //客户电话
        payOrder.setMemberNo(payOrderRequest.getMemberNo());     //会员卡号
        payOrder.setMemberAmt(payOrderRequest.getMemberAmt());    //会员支付金额
        payOrder.setPrintCount(payOrderRequest.getPrintCount());    //小票数量
        payOrder.setScore(payOrderRequest.getScore());      //积分
        payOrder.setAmt(Double.valueOf(payOrderRequest.getAmt()));   //金额
        payOrder.setStationId(payOrderRequest.getStationId());  //油站id
        payOrder.setStatus("0");         //创建订单 未支付状态 0
        payOrder.setPayType("sxf");      //支付类型
        if(StringUtils.isNotBlank(payOrderRequest.getUserType())&& payOrderRequest.getUserType().equals("1")){
            payOrder.setPayWay("02");        //支付方式：02公众号，03小程序',
        }else if(StringUtils.isNotBlank(payOrderRequest.getUserType())&& payOrderRequest.getUserType().equals("2")){
            payOrder.setPayWay("03");
        }
        //payOrder.setPayDate(new Date());                        //支付时间
        payOrder.setCreatedDate(new Date());                    //创建时间
        payOrder.setOrderType(payOrderRequest.getOrderType());  //订单类型
        //根据油站和油枪获取油枪编号和价格
        HashMap<String, Object> params = new HashMap<>();
        params.put("oilGunId", payOrderRequest.getOilGun());
        params.put("stationId", payOrderRequest.getStationId());
        String oilPersonnel = "";
        //使用list原因：(当时无班结管理先用list处理)一个枪号对应多个加油员场景
        List<Map> mapResultList = payOrderMapper.selectOilGunNoAndOilPrice(params);
        if(mapResultList != null && mapResultList.size() > 0){
            for (Map per : mapResultList){
                if(per.containsKey("personelName") && per.get("personelName").toString() !=null && per.get("personelName").toString() !=""){
                    oilPersonnel += per.get("personelName").toString() +",";
                }
            }
            if(oilPersonnel !=""){
                payOrder.setOilPersonnel(oilPersonnel.substring(0, oilPersonnel.length()-1));   //加油员
            }
            if(mapResultList.get(0).containsKey("oliGunNo") && mapResultList.get(0).get("oliGunNo").toString() !="" && mapResultList.get(0).get("oliGunNo").toString() !=null ){
                payOrder.setOilGun(mapResultList.get(0).get("oliGunNo").toString());                //存入油枪号
            }
            if(mapResultList.get(0).containsKey("stationName") && mapResultList.get(0).get("stationName").toString() !="" && mapResultList.get(0).get("stationName").toString() !=null ){
                payOrder.setStationName(mapResultList.get(0).get("stationName").toString());        //油站名称
            }
        }
        //根据油品名称和油站id获取当前油品调价信息
        params.put("oilName", payOrderRequest.getOilName());
        List<Map> oilPriceAdjustList = payOrderMapper.selectOilPriceAdjust(params);
        String amt = payOrderRequest.getAmt();  //订单金额
        if(oilPriceAdjustList != null && oilPriceAdjustList.size() > 0){  //若存在油价价格调整时
            for (Map m : oilPriceAdjustList){
                // 如果生效时间小于当前时间则使用生效时间 取离当前时间最近的调整价格（查询结果按生效时间降序排序故只做此判断即可）
                if(compareEffectTime(m.get("takeEffectDate").toString())){
                    if(m.containsKey("oilAdjustPrice") && m.get("oilAdjustPrice").toString() !=null && !m.get("oilAdjustPrice").toString().equals("")){
                        payOrder.setOrderLiters(recKonOrderLiters(amt, m.get("oilAdjustPrice").toString(), 2));       //计算加油升数且存入
                        payOrder.setOilPirce(m.get("oilAdjustPrice").toString());
                    }
                    break;
                }
            }
        }else {     //若没有油价调整时则使用原始油价计算加油升数
            if(mapResultList.get(0).containsKey("oilPrice") && mapResultList.get(0).get("oilPrice").toString() !=null && !mapResultList.get(0).get("oilPrice").toString().equals("")){
                String oilPrice = mapResultList.get(0).get("oilPrice").toString();    //原始价格
                payOrder.setOilPirce(oilPrice);
                payOrder.setOrderLiters(recKonOrderLiters(amt, oilPrice, 2));     //计算油价升数存放
            }
        }
        //数据落地
        payOrderMapper.insertSelective(payOrder);
        //根据订单号查询出订单
        PayOrderExample example=new PayOrderExample();
        example.or().andOrderNoEqualTo(ordNo);
        //根据订单号查询返回列表，最好是返回对象
        List<PayOrder> payOrderList= payOrderMapper.selectByExample(example);
        //返回订单号
        ordNo= payOrderList.get(0).getOrderNo();
        return ordNo;
    }

    /*
     * 计算加油升数
     * @param str1
     * @param str2
     * @param scale 保留小数位数
     * @return String
     */
    public String recKonOrderLiters(String str1, String str2, int scale){
        return  String.valueOf(new BigDecimal(str1).divide(new BigDecimal(str2), scale, BigDecimal.ROUND_HALF_UP).doubleValue());
    }

    /*
     * 判断油价生效时间是否小于当前时间
     * @param takeEffectDate
     * @return boolean
     */
    public boolean compareEffectTime(String takeEffectDate){
        boolean flag = false;
        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd hh:mm");
        try {
            Date teDate = df.parse(takeEffectDate);
            String currentTime = df.format(new Date());
            if(teDate.getTime() <= df.parse(currentTime).getTime()){
                flag = true;
            }
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return flag;
    }

    /*
     * 查询订单信息
     * */
    @Override
    public List<PayOrder> getPayOrderList(String orderNo) {
        PayOrderExample example =new PayOrderExample();
        example.or().andOrderNoEqualTo(orderNo);
        return payOrderMapper.selectByExample(example);
    }

    /**
     * 修改订单信息
     * @param payOrder
     */
    @Override
    public int getUpdatePayOrder(PayOrder payOrder) {
//        PayOrderExample example =new PayOrderExample();
//        example.or().andOrderIdEqualTo(payOrder.getOrderId());
        return payOrderMapper.updateOrderStatus(payOrder);
    }

    @Override
    public PayOrder searchPayOrder(Integer orderId) {
        PayOrder payOrder= payOrderMapper.selectByPrimaryKey(orderId);
        return payOrder;
    }
}
